# Contained React

Contained React is a library that mimics the logic of [Container Queries](https://developer.mozilla.org/en-US/docs/Web/CSS/CSS_Container_Queries) for React.

This library serves as a placeholder until we get `matchContainer` support for `HTMLElement`s, and this will be updated to support that natively.

- See CSSWG Draft for `matchContainer`.: https://github.com/w3c/csswg-drafts/issues/6205

## Usage

### Container Query

```tsx
import { useContainerQuery } from 'contained-react';

export function ContainerQuery() {
  const [ref, matches] = useContainerQuery('min-width: 700px');

  // matches will be true if the container is at least 700px wide
  return <div ref={ref}>{matches ? 'MATCH' : 'DOES NOT MATCH'}</div>;
}
```

[**See example**](/example/container-query)

### Container Queries

```tsx
export function ContainerQueries() {
  const [ref, matches] = useContainerQueries({
    smW: 'min-width: 700px',
    mdW: 'min-width: 1000px',
    smH: 'max-height: 300px',
    mdH: 'min-height: 301px',
  });

  return (
    <div ref={ref}>
      {matches['height'] && <div>height: {matches['height']}</div>}
      {matches['width'] && <div>width: {matches['width']}</div>}
    </div>
  );
}
```

[**See example**](/example/container-queries)
